import * as THREE from "three";
import { EventEmitter } from "events";
import { type GLTF, GLTFLoader } from "three/examples/jsm/loaders/GLTFLoader.js";
import { DRACOLoader } from "three/examples/jsm/loaders/DRACOLoader.js";
import { QuickThreejs } from "..";
export type LoadedItem = GLTF | THREE.Texture | THREE.CubeTexture | THREE.VideoTexture | AudioBuffer;
export interface Source {
    name: string;
    type: "cubeTexture" | "texture" | "gltfModel" | "video" | "audio";
    path: string | string[];
}
export default class Resources extends EventEmitter {
    app: QuickThreejs;
    sources: Source[];
    items: {
        [name: Source["name"]]: LoadedItem;
    };
    toLoad: number;
    loaded: number;
    loaders: {
        dracoLoader?: DRACOLoader;
        gltfLoader?: GLTFLoader;
        textureLoader?: THREE.TextureLoader;
        cubeTextureLoader?: THREE.CubeTextureLoader;
        audioLoader?: THREE.AudioLoader;
    };
    loadingManager: THREE.LoadingManager;
    private _videoLoader;
    constructor(sources?: Source[]);
    setSources(sources?: Source[]): number;
    addSource(source: Source): number;
    getSource(sourceName: string): Source | undefined;
    removeSource(sourceName: string): number;
    setLoaders(): void;
    setDracoLoader(dracoDecoderPath: string, linkWithGltfLoader?: boolean): void;
    startLoading(): void;
    sourceLoaded(source: Source, file: LoadedItem): void;
    destruct(): void;
}
